@@ -20,14 +20,17 @@ if not os.path.exists(default_path):
 
 
 def run_system_command(
-    command: str, exit_on_error: bool = True, stdout_error: bool = True
+    command: str,
+    exit_on_error: bool = True,
+    stdout_error: bool = True,
+    help: str = None,
 ):
     """Run commands against system
     Args:
         command (str): shell command
         exit_on_error (bool, optional): Exit on error. Defaults to True.
-        stdout_error (bool, optional): Print out the error. Defaults to True.
-
+        stdout_error (bool, optional): Print out the error. Defaults to True
+        help (str, optional): Help info incase of exception. Defaults to None.
     Returns:
         tuple : (is_successfull, object[Exception|Subprocess.run])
     """
@@ -45,8 +48,10 @@ def run_system_command(
     except subprocess.CalledProcessError as e:
         # Handle error if the command returns a non-zero exit code
         if stdout_error:
-            print(f"Error Occurred: while running '{command}'")
-            print(e.stderr)
+            click.secho(f"Error Occurred: while running '{command}'", fg="yellow")
+            click.secho(e.stderr, fg="red")
+            if help is not None:
+                click.secho(help, fg="cyan")
         sys.exit(e.returncode) if exit_on_error else None
         return (False, e)
 
@@ -198,14 +203,17 @@ class Conversation:
 
         return prompt
 
-    def update_chat_history(self, prompt: str, response: str) -> None:
+    def update_chat_history(
+        self, prompt: str, response: str, force: bool = False
+    ) -> None:
         """Updates chat history
 
         Args:
             prompt (str): user prompt
             response (str): LLM response
+            force (bool, optional): Force update
         """
-        if not self.status:
+        if not self.status and not force:
             return
         new_history = self.history_format % dict(user=prompt, llm=response)
         if self.file and self.update_file:
@@ -430,7 +438,7 @@ class RawDog:
     def __init__(
         self,
         quiet: bool = False,
-        external_exec: bool = False,
+        internal_exec: bool = False,
         confirm_script: bool = False,
         interpreter: str = "python",
         prettify: bool = True,
@@ -439,7 +447,7 @@ class RawDog:
 
         Args:
             quiet (bool, optional): Flag for control logging. Defaults to False.
-            external_exec (bool, optional): Execute scripts with system's python executable. Defaults to False.
+            internal_exec (bool, optional): Execute scripts with exec function. Defaults to False.
             confirm_script (bool, optional): Give consent to scripts prior to execution. Defaults to False.
             interpreter (str, optional): Python's interpreter name. Defaults to Python.
             prettify (bool, optional): Prettify the code on stdout. Defaults to True.
@@ -447,17 +455,27 @@ class RawDog:
         if not quiet:
             print(
                 "To get the most out of Rawdog. Ensure the following are installed:\n"
-                " 1. Python interpreter.\n"
+                " 1. Python 3.x\n"
                 " 2. Dependency:\n"
                 "  - Matplotlib\n"
                 "Be alerted on the risk posed! (Experimental)\n"
                 "Use '--quiet' to suppress this message and code/logs stdout.\n"
             )
-        self.external_exec = external_exec
+        self.internal_exec = internal_exec
         self.confirm_script = confirm_script
         self.quiet = quiet
         self.interpreter = interpreter
         self.prettify = prettify
+        self.python_version = (
+            f"{sys.version_info.major}.{sys.version_info.minor}.{sys.version_info.micro}"
+            if self.internal_exec
+            else run_system_command(
+                f"{self.interpreter} --version",
+                exit_on_error=True,
+                stdout_error=True,
+                help="If you're using pytgpt-cli, use the flag '--internal-exec'",
+            )[1].stdout.split(" ")[1]
+        )
 
     @property
     def intro_prompt(self):
@@ -507,7 +525,7 @@ Please follow these conventions carefully:
 - ALWAYS Return your SCRIPT inside of a single pair of ``` delimiters. Only the console output of the first such SCRIPT is visible to the user, so make sure that it's complete and don't bother returning anything else.
 
 Current system : {platform.system()}
-Python version : {run_system_command(f"{self.interpreter} --version",exit_on_error=True,stdout_error=True)[1].stdout.split(' ')[1]}
+Python version : {self.python_version}
 Current directory : {os.getcwd()}
 Current Datetime : {datetime.datetime.now()}
 """
@@ -565,7 +583,7 @@ Current Datetime : {datetime.datetime.now()}
 
             raw_code_plus = re.sub(r"(```)(python)?", "", raw_code)
 
-            if "CONTINUE" in response or self.external_exec:
+            if "CONTINUE" in response or not self.internal_exec:
                 self.log("Executing script externally")
                 path_to_script = os.path.join(default_path, "execute_this.py")
                 with open(path_to_script, "w") as fh:
@@ -593,7 +611,8 @@ Current Datetime : {datetime.datetime.now()}
                     exec(raw_code_plus)
                 except Exception as e:
                     self.log(
-                        "Exception occurred while executing script. Responding with error.",
+                        "Exception occurred while executing script. Responding with error: "
+                        f"{e.args[1] if len(e.args)>1 else str(e)}",
                         "error",
                     )
                     return f"PREVIOUS SCRIPT EXCEPTION:\n{str(e)}"
