@@ -3,7 +3,7 @@ import tests.base as base
 from pytgpt.opengpt import OPENGPT
 
 
-class TestLeo(base.llmBase):
+class TestOpengpt(base.llmBase):
     def setUp(self):
         self.bot = OPENGPT()
         self.prompt = base.prompt
